@@ -1,6 +1,6 @@
 package App::RecordStream::Operation;
 
-our $VERSION = "3.4";
+our $VERSION = "3.7.4";
 
 use strict;
 use warnings;
@@ -210,9 +210,10 @@ sub add_help_type {
 }
 
 sub parse_options {
-  my $this         = shift;
-  my $args         = shift || [];
-  my $options_spec = shift || {};
+  my $this                  = shift;
+  my $args                  = shift || [];
+  my $options_spec          = shift || {};
+  my $configuration_options = shift || [];
 
   # Add help options
   foreach my $help_type (keys %{$this->{'HELP_TYPES'}}) {
@@ -230,14 +231,20 @@ sub parse_options {
   # Add filename annotation option
   $options_spec->{'--filename-key|fk=s'} = \($this->{'FILENAME_KEY'});
 
+  my $starting_config = Getopt::Long::Configure();
+
+  # Push custom configuration
+  Getopt::Long::Configure('no_ignore_case', @$configuration_options);
 
-  Getopt::Long::Configure('no_ignore_case');
   local @ARGV = @$args;
   unless (GetOptions(%$options_spec)) {
     # output usage if there was a problem with option parsing
     $this->_set_wants_help(1);
   }
 
+  # Restore original configuration
+  Getopt::Long::Configure($starting_config);
+
   @$args = @ARGV;
 }
 
@@ -384,7 +391,7 @@ sub push_record {
     ${$record->guess_key_from_spec($this->{'FILENAME_KEY'})} = get_current_filename();
   }
 
-  $this->{'NEXT'}->accept_record($record);
+  return $this->{'NEXT'}->accept_record($record);
 }
 
 sub push_line {
