@@ -1,6 +1,6 @@
 package App::RecordStream::Operation::generate;
 
-our $VERSION = "3.4";
+our $VERSION = "3.7.4";
 
 use strict;
 
@@ -28,8 +28,7 @@ sub init {
     $executor_options->arguments(),
   };
 
-  Getopt::Long::Configure('no_ignore_case');
-  $this->parse_options($args, $spec);
+  $this->parse_options($args, $spec, ['bundling']);
 
   my $expression = $executor_options->get_string($args);
   my $executor = App::RecordStream::Executor->new($expression);
@@ -81,6 +80,7 @@ sub usage
   my $this = shift;
 
   my $options = [
+    App::RecordStream::Executor::options_help(),
     [ 'passthrough', 'Emit input record in addition to generated records' ],
     [ 'keychain <name>', 'Use \'name\' as the chain key (default is \'_chain\') may be a key spec, see \'--help-keyspecs\' for more info' ],
   ];
